# README

* reference example https://joss.readthedocs.io/en/latest/index.html

```sh
---
title: 'automesh: A Rust crate for automatic mesh generation'
tags:
  - Rust
  - segmentation
  - computational geometry
  - finite element mesh
authors:
  - name: Chad B. Hovey
    orcid: 0000-0003-0915-5765
    equal-contrib: true
    affiliation: 1
  - name: Michael R. Buche
    orcid: 0000-0003-1892-0502
    equal-contrib: true
    affiliation: 1
affiliations:
 - name: Sandia National Laboratories, United States
   index: 1
date: 30 April 2025
bibliography: paper.bib

# Optional fields if submitting to a AAS journal too, see this blog post:
# https://blog.joss.theoj.org/2018/12/a-new-collaboration-with-aas-publishing
# aas-doi: 10.3847/xxxxx <- update this with the DOI from AAS once you know it.
# aas-journal: Astrophysical Journal <- The name of the AAS journal.
---
```
